<?php
/************************************************************************
 * Mailer-Project 0.2.1-FINAL                         Start: 01/07/2005 *
 * ==========================                   Last change: 01/07/2005 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : ext-coupon.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : Coupon system                                    *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Coupon-System                                    *
 * -------------------------------------------------------------------- *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Version number
setThisExtensionVersion('0.0');

// Version history array (add more with , '0.1' and so on)
setExtensionVersionHistory(array('0.0'));

switch (getExtensionMode()) {
	case 'register': // Do stuff when installtion is running
		// This extension requires an up-to-date user
		addExtensionDependency('user');

		// Coupon data
		addDropTableSql('coupon_data');
		addCreateTableSql('coupon_data', "(
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`coupon_created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
`coupon_expired` TIMESTAMP NULL DEFAULT NULL,
`coupon_type` ENUM('CODE','API') NOT NULL DEFAULT 'CODE',
`total_created` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`total_cashed` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`points` FLOAT(20,5) NOT NULL DEFAULT 0.00000,
`coupon_description` TEXT,
PRIMARY KEY (`id`)
) TYPE = {?_TABLE_TYPE?} CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT = 'Created coupons'");

		// Coupon->user connection table
		addDropTableSql('user_coupons');
		addCreateTableSql('user_coupons', "(
`id` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
`coupon_id` BIGINT(20) UNSIGNED NOT NULL DEFAULT 0,
`userid` BIGINT(2) UNSIGNED NOT NULL DEFAULT 0,
`coupon_code` VARCHAR(30) NULL DEFAULT NULL,
`cashed_on` TIMESTAMP NULL DEFAULT NULL,
PRIMARY KEY (`id`),
UNIQUE KEY `coupon_user` (`coupon_id`,`userid`),
UNIQUE KEY (`coupon_code`)
) TYPE = {?_TABLE_TYPE?} CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT = 'Coupon->user connection'");

		// Configuration entries
		addConfigAddSql('coupon_default_time', 'BIGINT(20) NOT NULL DEFAULT ' . (getOneDay() * 7));
		addConfigAddSql('coupon_default_points', 'FLOAT(20,5) NOT NULL DEFAULT 100.00000');
		addConfigAddSql('coupon_points_account', "ENUM('ORDER','GENERAL') NOT NULL DEFAULT 'ORDER'");
		addConfigAddSql('coupon_payment_method', "ENUM('DIRECT','REF') NOT NULL DEFAULT 'DIRECT'");
		addConfigAddSql('coupon_locked_points_mode', "ENUM('LOCKED','UNLOCKED') NOT NULL DEFAULT 'LOCKED'");
		addConfigAddSql('coupon_autopurge_time', 'BIGINT(20) NOT NULL DEFAULT ' . (getOneDay() * 7));
		addConfigAddSql('coupon_userid', 'BIGINT(20) UNSIGNED NOT NULL DEFAULT 0');

		// User data table
		addExtensionSql("ALTER TABLE `{?_MYSQL_PREFIX?}_user_data` ADD `receiving_coupons` ENUM('Y','N') NOT NULL DEFAULT 'Y'");

		// Menu systems:
		//  - Admin entries
		addAdminMenuSql('coupon', NULL, 'Gutscheine', 'Einrichten und Versenden von Code-Gutscheinen, sowie per API (noch in Planung). Bei Code-Gutscheinen wird ein Code pro Mitglied erzeugt, der dann an das Mitglied ausgesandt wird. L&ouml;st das Mitglied den Gutschein ein, erh&auml;lt es die Gutschrift auf sein Konto gutgeschrieben. Ausgangseinstellung ist die Gutschrift auf das Werbeguthaben, was f&uuml;r Paidmailer von Wichtigkeit ist, dass Guthaben aus Gutscheinen nicht auszahlungsf&auml;hig ist.', 6);
		addAdminMenuSql('coupon', 'list_coupon', 'Auflisten', 'Listet alle Gutscheine und Einl&ouml;sungen durch die Mitglieder auf.', 1);
		addAdminMenuSql('coupon', 'send_coupon', 'Versenden/Neuen erstellen', 'Versendet neue Gutscheine an die Mitglieder. Wenn Sie auf &quot;Absenden&quot; klicken, warten Sie bitte die Folgeseite ab, da der Versand der Gutscheine derzeit nicht gepoolt ist.', 2);
		addAdminMenuSql('coupon', 'config_coupon', 'Einstellungen', 'Allgemeine Einstellungen zu Code-Gutscheinen und Gutscheinen von Sponsoren (z.B. per API) k&ouml;nnen hier vorgenommen werden.', 3);
		//  - Member entries
		addMemberMenuSql('coupon', NULL, 'Gutscheine', 'N', 'Y', 3);
		addMemberMenuSql('coupon', 'cash_coupon', 'Gutschein einl&ouml;sen', 'N', 'Y', 1);
		addMemberMenuSql('coupon', 'list_coupon', 'Eingel&ouml;ste auflisten', 'N', 'Y', 2);

		// Add filter (for changing user_points column dynamically
		registerFilter('determine_points_column_name', 'COUPON_CHANGE_POINTS_COLUMN_NAME', false, true, isExtensionDryRun());
		break;

	case 'remove': // Do stuff when removing extension
		// SQL commands to run
		addDropTableSql('coupon_data');
		addDropTableSql('user_coupons');
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_admin_menu` WHERE `action`='coupon' LIMIT 4");
		addExtensionSql("DELETE LOW_PRIORITY FROM `{?_MYSQL_PREFIX?}_member_menu` WHERE `action`='coupon' LIMIT 3");

		// Remove all filters
		unregisterFilter(__FUNCTION__, __LINE__, 'determine_points_column_name', 'COUPON_CHANGE_POINTS_COLUMN_NAME', true, isExtensionDryRun());
		break;

	case 'activate': // Do stuff when admin activates this extension
		// SQL commands to run
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_member_menu` SET `visible`='Y', `locked`='N' WHERE `action`='coupon' LIMIT 3");
		break;

	case 'deactivate': // Do stuff when admin deactivates this extension
		// SQL commands to run
		addExtensionSql("UPDATE `{?_MYSQL_PREFIX?}_member_menu` SET `visible`='N', `locked`='Y' WHERE `action`='coupon' LIMIT 3");
		break;

	case 'update': // Update an extension
		switch (getCurrentExtensionVersion()) {
			case '0.0.1': // SQL queries for v0.0.1
				addExtensionSql('');

				// Update notes (these will be set as task text!)
				setExtensionUpdateNotes('');
				break;
		} // END - switch
		break;

	case 'modify': // When the extension got modified
		break;

	case 'test': // For testing purposes
		break;

	case 'init': // Do stuff when extension is initialized
		break;

	default: // Unknown extension mode
		logDebugMessage(__FILE__, __LINE__, sprintf("Unknown extension mode %s in extension %s detected.", getExtensionMode(), getCurrentExtensionName()));
		break;
} // END - switch

// [EOF]
?>
