<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 06/02/2011 *
 * ===================                          Last change: 06/02/2011 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : _filter.php                                      *
 * -------------------------------------------------------------------- *
 * Short description : Filters for ext-                                 *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Filter fuer ext-                                 *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Filter for adding extra data to the query
function FILTER_ADD_EXTRA_SQL_DATA ($add = '') {
	// Is the admins extension updated? (should be!)
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	if (isExtensionInstalledAndNewer('admins', '0.3.0')) $add .= ', `default_acl` AS def_acl';
	if (isExtensionInstalledAndNewer('admins', '0.6.7')) $add .= ', `la_mode`';
	if (isExtensionInstalledAndNewer('admins', '0.7.2')) $add .= ', `login_failures`, UNIX_TIMESTAMP(`last_failure`) AS last_failure';
	if (isExtensionInstalledAndNewer('admins', '0.7.3')) $add .= ', `expert_settings`, `expert_warning`';

	// Return it
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $add;
}

// Reset the login failures
function FILTER_RESET_ADMINS_LOGIN_FAILURES ($data) {
	// Store it in session
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	setSession('mailer_admin_failures'    , getAdminLoginFailures($data['id']));
	setSession('mailer_admin_last_failure', getAdminLastFailure($data['id']));

	// Prepare update data
	$postData['login'][getCurrentAdminId()]          = $data['login'];
	$postData['login_failures'][getCurrentAdminId()] = '0';
	$postData['last_failure'][getCurrentAdminId()]   = null;

	// Change it in the admin
	adminsChangeAdminAccount($postData);

	// Always make sure the cache is destroyed
	rebuildCache('admin');

	// Return the data for further processing
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $data;
}

// Count the login failure
function FILTER_COUNT_ADMINS_LOGIN_FAILURE ($data) {
	// Prepare update data
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	$postData['login'][getCurrentAdminId()]          = $data['login'];
	$postData['login_failures'][getCurrentAdminId()] = '`login_failures`+1';
	$postData['last_failure'][getCurrentAdminId()]   = 'NOW()';

	// Change it in the admin
	adminsChangeAdminAccount($postData);

	// Always make sure the cache is destroyed
	rebuildCache('admin');

	// Return the data for further processing
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $data;
}

// Rehashes the given plain admin password and stores it the database
function FILTER_REHASH_ADMINS_PASSWORD ($data) {
	// Generate new hash
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Called!');
	$newHash = generateHash($data['plain_pass']);

	// Prepare update data
	$postData['login'][getCurrentAdminId()]    = $data['login'];
	$postData['password'][getCurrentAdminId()] = $newHash;

	// Change it in the admin
	adminsChangeAdminAccount($postData);

	// Update cookie/session and data array
	setAdminMd5(encodeHashForCookie($newHash));
	$data['pass_hash'] = $newHash;

	// Always make sure the cache is destroyed
	rebuildCache('admin');

	// Return the data for further processing
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'Done!');
	return $data;
}

// [EOF]
?>
